@@ -5,7 +5,6 @@ import signal
 import time
 
 import requests
-import compose.cli.command
 
 
 class TimeoutError(Exception):
@@ -51,22 +50,9 @@ def wait_for_marathon():
             break
 
 
-def get_compose_service(service_name):
-    """Returns a compose object for the service"""
-    project = compose.cli.command.get_project(os.path.dirname(os.path.realpath(__file__)))
-    return project.get_service(service_name)
-
-
 def get_marathon_connection_string():
     # only reliable way I can detect travis..
     if '/travis/' in os.environ.get('PATH'):
         return 'localhost:8080'
     else:
-        service_port = get_service_internal_port('marathon')
-        return "localhost:%s" % service_port.published
-
-
-def get_service_internal_port(service_name):
-    """Gets the exposed port for service_name from docker-compose.yml. If there are
-    multiple ports. It returns the first one."""
-    return get_compose_service(service_name).options['ports'][0]
+        return "localhost:18080"
