@@ -1,7 +1,6 @@
-import logging
-
 from .client import MarathonClient
 from .models import MarathonResource, MarathonApp, MarathonTask, MarathonConstraint
 from .exceptions import MarathonError, MarathonHttpError, NotFoundError, InvalidChoiceError
+from .util import get_log
 
-log = logging.getLogger(__name__)
+log = get_log()
