@@ -206,7 +206,7 @@ class EventFactory:
         'pod_deleted_event': MarathonPodDeletedEvent,
     }
 
-    class_to_event = dict((v, k) for k, v in event_to_class.items())
+    class_to_event = {v: k for k, v in event_to_class.items()}
 
     def process(self, event):
         event_type = event['eventType']
@@ -214,4 +214,4 @@ class EventFactory:
             clazz = self.event_to_class[event_type]
             return clazz.from_json(event)
         else:
-            raise MarathonError('Unknown event_type: {}, data: {}'.format(event_type, event))
+            raise MarathonError(f'Unknown event_type: {event_type}, data: {event}')
