@@ -8,17 +8,11 @@ except ImportError:
     import simplejson as json
 import re
 
-from ._compat import string_types
-
 
 def get_log():
     return logging.getLogger(__name__.split('.')[0])
 
 
-def is_stringy(obj):
-    return isinstance(obj, string_types)
-
-
 class MarathonJsonEncoder(json.JSONEncoder):
 
     """Custom JSON encoder for Marathon object serialization."""
@@ -30,7 +24,7 @@ class MarathonJsonEncoder(json.JSONEncoder):
         if isinstance(obj, datetime.datetime):
             return obj.strftime('%Y-%m-%dT%H:%M:%S.%fZ')
 
-        if isinstance(obj, collections.Iterable) and not is_stringy(obj):
+        if isinstance(obj, collections.Iterable) and not isinstance(obj, str):
             try:
                 return {k: self.default(v) for k, v in obj.items()}
             except AttributeError:
@@ -50,7 +44,7 @@ class MarathonMinimalJsonEncoder(json.JSONEncoder):
         if isinstance(obj, datetime.datetime):
             return obj.strftime('%Y-%m-%dT%H:%M:%S.%fZ')
 
-        if isinstance(obj, collections.Iterable) and not is_stringy(obj):
+        if isinstance(obj, collections.Iterable) and not isinstance(obj, str):
             try:
                 return {k: self.default(v) for k, v in obj.items() if (v or v in (False, 0))}
             except AttributeError:
@@ -67,3 +61,21 @@ def to_camel_case(snake_str):
 def to_snake_case(camel_str):
     s1 = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', camel_str)
     return re.sub('([a-z0-9])([A-Z])', r'\1_\2', s1).lower()
+
+
+DATETIME_FORMATS = [
+    '%Y-%m-%dT%H:%M:%S.%fZ',
+    '%Y-%m-%dT%H:%M:%SZ',  # Marathon omits milliseconds when they would be .000
+]
+
+
+def to_datetime(timestamp):
+    if (timestamp is None or isinstance(timestamp, datetime.datetime)):
+        return timestamp
+    else:
+        for fmt in DATETIME_FORMATS:
+            try:
+                return datetime.datetime.strptime(timestamp, fmt).replace(tzinfo=datetime.timezone.utc)
+            except ValueError:
+                pass
+        raise ValueError(f'Unrecognized datetime format: {timestamp}')
